summaryrefslogtreecommitdiffstats
path: root/src/configdialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/configdialog.cpp')
-rw-r--r--src/configdialog.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/configdialog.cpp b/src/configdialog.cpp
index 341ab58..c53930f 100644
--- a/src/configdialog.cpp
+++ b/src/configdialog.cpp
@@ -67,23 +67,23 @@ email : markey@web.de
#include <ntqlistview.h>
#include <ntqcheckbox.h>
-#include <kapplication.h> //kapp
+#include <tdeapplication.h> //kapp
#include <kcombobox.h>
#include <kiconloader.h>
#include <klineedit.h>
-#include <klocale.h>
+#include <tdelocale.h>
#include <kstandarddirs.h>
#include <kdebug.h>
#include <dcopref.h>
-#include <kconfig.h>
-#include <kmessagebox.h>
+#include <tdeconfig.h>
+#include <tdemessagebox.h>
//////////////////////////////////////////////////////////////////////////////////////////
// PUBLIC
//////////////////////////////////////////////////////////////////////////////////////////
-TorkConfigDialog::TorkConfigDialog( TQWidget *parent, const char* name, KConfigSkeleton *config )
- : KConfigDialog( parent, name, config ),m_parent(parent)
+TorkConfigDialog::TorkConfigDialog( TQWidget *parent, const char* name, TDEConfigSkeleton *config )
+ : TDEConfigDialog( parent, name, config ),m_parent(parent)
{
setWFlags( WDestructiveClose );
@@ -137,7 +137,7 @@ TorkConfigDialog::TorkConfigDialog( TQWidget *parent, const char* name, KConfigS
static_cast<TQLabel*>(label)->setPixmap( TQMessageBox::standardIcon( TQMessageBox::Information ) );
delete list;
- //stop KFont Requesters getting stupidly large
+ //stop TDEFont Requesters getting stupidly large
list = queryList( "TQLabel", "m_sampleLabel" );
for( TQObject *label = list->first(); label; label = list->next() )
static_cast<TQLabel*>(label)->setMaximumWidth( 250 );
@@ -229,19 +229,19 @@ void TorkConfigDialog::showPage( const TQCString& page )
{
for( uint index = 0; index < m_pageList.count(); index++ ) {
if ( m_pageList[index]->name() == page ) {
- KConfigDialog::showPage( index );
+ TDEConfigDialog::showPage( index );
return;
}
}
}
/** Reimplemented from KConfigDialog */
void TorkConfigDialog::addPage( TQWidget *page, const TQString &itemName, const TQString &pixmapName, const TQString &header, bool manage )
{
// Add the widget pointer to our list, for later reference
m_pageList << page;
- KConfigDialog::addPage( page, itemName, pixmapName, header, manage );
+ TDEConfigDialog::addPage( page, itemName, pixmapName, header, manage );
}
@@ -258,7 +258,7 @@ void TorkConfigDialog::updateCustomSettings()
//When settings are changed in the config dialog, this is called
//to update all possibly changed values and apply them to Tor.
- //TQListViews need to be handled outside of kconfigxt
+ //TQListViews need to be handled outside of tdeconfigxt
TorkConfig::setQuickConfigure( m_quickconfig->QuickConfigure->currentItem() );
TorkConfig::setAccountingStart(m_myserver->AccountingStart->currentText());
@@ -229,19 +229,19 @@ void TorkConfigDialog::showPage( const TQCString& page )
}
}
-/** Reimplemented from KConfigDialog */
+/** Reimplemented from TDEConfigDialog */
void TorkConfigDialog::addPage( TQWidget *page, const TQString &itemName, const TQString &pixmapName, const TQString &header, bool manage )
{